@@ -72,40 +72,36 @@ impl ConfigSerializer {
         for state in config.initial_state.iter() {
             serialize_integer_to_vec!(data, *state.0, u32);
             let mut serialized_state = state.1.serialize();
-            serialize_integer_to_vec!(data, serialized_state.len() as u8, u8);
+            serialize_integer_to_vec!(data, serialized_state.len(), u8);
             data.append(&mut serialized_state);
         }
 
         serialize_integer_to_vec!(data, config.event_processors.len(), u32);
 
         for event_processor in config.event_processors.iter() {
-            serialize_integer_to_vec!(data, event_processor.matchers.len(), u32);
-
-            for matcher in event_processor.matchers.iter() {
-                let mut matcher = matcher.serialize();
-                serialize_integer_to_vec!(data, matcher.len() as u32, u32);
-                data.append(&mut matcher);
-            }
+            let mut matcher = event_processor.matcher.serialize();
+            serialize_integer_to_vec!(data, matcher.len(), u32);
+            data.append(&mut matcher);
 
             serialize_integer_to_vec!(data, event_processor.creators.len(), u32);
 
             for creator in event_processor.creators.iter() {
                 serialize_integer_to_vec!(data, creator.extractor.get_code(), u16);
                 let mut extractor = creator.extractor.serialize();
-                serialize_integer_to_vec!(data, extractor.len() as u8, u8);
+                serialize_integer_to_vec!(data, extractor.len(), u8);
                 data.append(&mut extractor);
 
                 serialize_integer_to_vec!(data, creator.producer.get_code(), u16);
                 let mut producer = creator.producer.serialize();
-                serialize_integer_to_vec!(data, producer.len() as u8, u8);
+                serialize_integer_to_vec!(data, producer.len(), u8);
                 data.append(&mut producer);
 
-                let matcher_count = if creator.matcher.is_some() { 1 } else { 0 };
-                serialize_integer_to_vec!(data, matcher_count, u8);
+                let matcher_exists = if creator.matcher.is_some() { 1 } else { 0 };
+                serialize_integer_to_vec!(data, matcher_exists, u8);
 
                 if let Some(matcher) = &creator.matcher {
                     let mut matcher = matcher.serialize();
-                    serialize_integer_to_vec!(data, matcher.len() as u32, u32);
+                    serialize_integer_to_vec!(data, matcher.len(), u32);
                     data.append(&mut matcher);
                 }
             }
@@ -131,29 +127,20 @@ impl ConfigSerializer {
             initial_state.insert(state_index, state_value);
         }
 
-        let event_processor_count = try_deserialize_integer_from_vec!(data, offset, u32);
+        let event_processor_count = try_deserialize_integer_from_vec!(data, offset, u32) as usize;
 
         let mut event_processors = vec![];
-        event_processors.reserve(event_processor_count as usize);
+        event_processors.reserve(event_processor_count);
 
         for _ in 0..event_processor_count {
-            let matcher_count = try_deserialize_integer_from_vec!(data, offset, u32);
+            let matcher_len = try_deserialize_integer_from_vec!(data, offset, u32) as usize;
+            let matcher = *Matcher::try_deserialize(&data[offset..offset + matcher_len])?;
+            offset += matcher_len;
 
-            let mut matchers = vec![];
-            matchers.reserve(matcher_count as usize);
-
-            for _ in 0..matcher_count {
-                let matcher_len = try_deserialize_integer_from_vec!(data, offset, u32) as usize;
-                matchers.push(*Matcher::try_deserialize(
-                    &data[offset..offset + matcher_len],
-                )?);
-                offset += matcher_len;
-            }
-
-            let creator_count = try_deserialize_integer_from_vec!(data, offset, u32);
+            let creator_count = try_deserialize_integer_from_vec!(data, offset, u32) as usize;
 
             let mut creators = vec![];
-            creators.reserve(creator_count as usize);
+            creators.reserve(creator_count);
 
             for _ in 0..creator_count {
                 let extractor_code = try_deserialize_integer_from_vec!(data, offset, u16);
@@ -173,8 +160,8 @@ impl ConfigSerializer {
                 offset += producer_len;
 
                 let mut matcher = None;
-                let matcher_count = try_deserialize_integer_from_vec!(data, offset, u8);
-                if matcher_count != 0 {
+                let matcher_exists = try_deserialize_integer_from_vec!(data, offset, u8) != 0;
+                if matcher_exists {
                     let matcher_len = try_deserialize_integer_from_vec!(data, offset, u32) as usize;
                     matcher = Some(*Matcher::try_deserialize(
                         &data[offset..offset + matcher_len],
@@ -189,7 +176,7 @@ impl ConfigSerializer {
                 });
             }
 
-            event_processors.push(EventProcessor { matchers, creators });
+            event_processors.push(EventProcessor { matcher, creators });
         }
 
         Ok(Config {
@@ -239,6 +226,9 @@ impl ConfigSerializer {
             SET_STATE_TO_CONST_FILTER_CODE => Ok(SetStateToConstFilter::try_deserialize(data)?),
             SET_STATE_TO_VALUE_FILTER_CODE => Ok(SetStateToValueFilter::try_deserialize(data)?),
             FLIP_STATE_FILTER_CODE => Ok(FlipStateFilter::try_deserialize(data)?),
+            TIME_MATCHES_CRON_EXPRESSION_FILTER_CODE => {
+                Ok(TimeMatchesCronExpressionFilter::try_deserialize(data)?)
+            }
             _ => Err(ConfigSerializerError::UnknownExtractor),
         }
     }
@@ -273,10 +263,10 @@ mod tests {
 
         let mut event_processors = vec![];
         event_processors.push(EventProcessor {
-            matchers: vec![Matcher::Single {
+            matcher: Matcher::Single {
                 extractor: Box::new(EventCodeExtractor::new()),
                 filter: Box::new(ValueEqualToConstFilter::new(Value::U8(0xff))),
-            }],
+            },
             creators: vec![Creator {
                 extractor: Box::new(NoneExtractor::new()),
                 producer: Box::new(BcmChangeBrightnessStateProducer::new(0xabab, 0xff, 0)),
@@ -297,7 +287,6 @@ mod tests {
             0x02, // state value len
             0x00, 0xff, // state value
             0x00, 0x00, 0x00, 0x01, // event processor count
-            0x00, 0x00, 0x00, 0x01, // matcher count
             0x00, 0x00, 0x00, 0x09, // matcher len
             0x00, // matcher enum code
             0x00, 0x02, // EVENT_CODE_EXTRACTOR_CODE
@@ -313,7 +302,7 @@ mod tests {
             0xab, 0xab, // bcm_address
             0xff, // channel
             0x00, 0x00, 0x00, 0x00, // state_index
-            0x00, // matcher count
+            0x00, // matcher exists
         ];
 
         assert_eq!(data, expected_data);
@@ -349,7 +338,6 @@ mod tests {
             0x02, // state value len
             0x00, 0xff, // state value
             0x00, 0x00, 0x00, 0x01, // event processor count
-            0x00, 0x00, 0x00, 0x01, // matcher count
             0x00, 0x00, 0x00, 0x09, // matcher len
             0x00, // matcher enum code
             0x00, 0x02, // EVENT_CODE_EXTRACTOR_CODE
@@ -365,7 +353,7 @@ mod tests {
             0xab, 0xab, // bcm_address
             0xff, // channel
             0x00, 0x00, 0x00, 0x00, // state_index
-            0x00, // matcher count
+            0x00, // matcher exists
         ];
 
         let config = ConfigSerializer::deserialize(&data).unwrap();
@@ -382,10 +370,10 @@ mod tests {
 
         let mut event_processors = vec![];
         event_processors.push(EventProcessor {
-            matchers: vec![Matcher::Single {
+            matcher: Matcher::Single {
                 extractor: Box::new(EventCodeExtractor::new()),
                 filter: Box::new(ValueEqualToConstFilter::new(Value::U8(0xff))),
-            }],
+            },
             creators: vec![Creator {
                 extractor: Box::new(NoneExtractor::new()),
                 producer: Box::new(BcmChangeBrightnessStateProducer::new(0xabab, 0xff, 0)),
@@ -409,7 +397,6 @@ mod tests {
             0x02, // state_value len
             0x00, 0xff, // state_value
             0x00, 0x00, 0x00, 0x01, // event processor count
-            0x00, 0x00, 0x00, 0x01, // matcher count
             0x00, 0x00, 0x00, 0x09, // matcher len
             0x00, // matcher enum code
             0x00, 0x02, // EVENT_CODE_EXTRACTOR_CODE
@@ -425,7 +412,7 @@ mod tests {
             0xab, 0xab, // bcm_address
             0xff, // channel
             0x00, 0x00, 0x00, 0x00, // state_index
-            0x01, // matcher count
+            0x01, // matcher exists
             0x00, 0x00, 0x00, 0x09, // matcher len
             0x00, // matcher enum code
             0x00, 0x02, // EVENT_CODE_EXTRACTOR_CODE
@@ -446,7 +433,6 @@ mod tests {
             0x02, // state_value len
             0x00, 0xff, // state_value
             0x00, 0x00, 0x00, 0x01, // event processor count
-            0x00, 0x00, 0x00, 0x01, // matcher count
             0x00, 0x00, 0x00, 0x09, // matcher len
             0x00, // matcher enum code
             0x00, 0x02, // EVENT_CODE_EXTRACTOR_CODE
@@ -462,7 +448,7 @@ mod tests {
             0xab, 0xab, // bcm_address
             0xff, // channel
             0x00, 0x00, 0x00, 0x00, // state_index
-            0x01, // matcher count
+            0x01, // matcher exists
             0x00, 0x00, 0x00, 0x09, // matcher len
             0x00, // matcher enum code
             0x00, 0x02, // EVENT_CODE_EXTRACTOR_CODE
